@@ -1,18 +1,19 @@
 <?php
 
-$block_name = _("Month View");
+$block_name = _("This Month");
 
 /**
  * Horde_Block_Kronolith_month:: Implementation of the Horde_Block API
  * to display a mini month view of calendar items.
  *
- * $Horde: kronolith/lib/Block/month.php,v 1.21.2.7 2006/01/03 20:50:17 chuck Exp $
+ * $Horde: kronolith/lib/Block/month.php,v 1.21.2.10 2008/09/17 08:53:57 jan Exp $
  *
  * @package Horde_Block
  */
 class Horde_Block_Kronolith_month extends Horde_Block {
 
     var $_app = 'kronolith';
+    var $_share = null;
 
     function _params()
     {
@@ -37,8 +38,16 @@ class Horde_Block_Kronolith_month extends Horde_Block {
     function _title()
     {
         global $registry;
-        return Horde::link(Horde::url($registry->getInitialPage(), true)) . strftime('%B, %Y') . '</a> <small>' .
-            Horde::link(Horde::applicationUrl('addevent.php', true)) . Horde::img('new.png', _("New Event")) . ' ' . _("New Event") . '</a></small>';
+        require_once dirname(__FILE__) . '/../base.php';
+
+        $title = _("All Calendars");
+        if (isset($this->_params['calendar']) && $this->_params['calendar'] != '__all') {
+            $this->_share = &$GLOBALS['kronolith_shares']->getShare($this->_params['calendar']);
+            if (!is_a($this->_share, 'PEAR_Error')) {
+                $title = htmlspecialchars($this->_share->get('name'));
+            }
+        }
+        return $title . ', ' . Horde::link(Horde::url($registry->getInitialPage(), true)) . strftime('%B, %Y') . '</a>';
     }
 
     /**
@@ -52,15 +61,24 @@ class Horde_Block_Kronolith_month extends Horde_Block {
         require_once dirname(__FILE__) . '/../base.php';
         require_once KRONOLITH_BASE . '/lib/Day.php';
 
+        if ($this->_params['calendar'] != '__all') {
+            if (empty($this->_share)) {
+                $this->_share = $GLOBALS['kronolith_shares']->getShare($this->_params['calendar']);
+            }
+            if (!$this->_share->hasPermission(Auth::getAuth(), PERMS_SHOW)) {
+                return _("Permission Denied");
+            }
+        }
+
         Horde::addScriptFile('tooltip.js', 'horde', true);
 
         $year = date('Y');
         $month = date('m');
         $today = mktime(0, 0, 0, date('n'), date('j'), date('Y'));
 
-        $startday = &new Horde_Date(array('mday' => 1,
-                                          'month' => $month,
-                                          'year' => $year));
+        $startday = new Horde_Date(array('mday' => 1,
+                                         'month' => $month,
+                                         'year' => $year));
         $startday = $startday->dayOfWeek();
         $daysInView = Date_Calc::weeksInMonth($month, $year) * 7;
         if (!$prefs->getValue('week_start_monday')) {
@@ -71,9 +89,9 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             if ($startday == HORDE_DATE_SUNDAY) {
                 $daysInView -= 7;
             }
-            $endday = &new Horde_Date(array('mday' => Horde_Date::daysInMonth($month, $year),
-                                            'month' => $month,
-                                            'year' => $year));
+            $endday = new Horde_Date(array('mday' => Horde_Date::daysInMonth($month, $year),
+                                           'month' => $month,
+                                           'year' => $year));
             $endday = $endday->dayOfWeek();
             if ($endday == HORDE_DATE_SUNDAY) {
                 $daysInView += 7;
@@ -86,15 +104,9 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             }
         }
 
-        $startDate = &new Horde_Date(array('year' => $year,
-                                           'month' => $month,
-                                           'mday' => $startOfView));
-        $endDate = &new Horde_Date(array('year' => $year,
-                                         'month' => $month,
-                                         'mday' => $startOfView + $daysInView,
-                                         'hour' => 23,
-                                         'min' => 59,
-                                         'sec' => 59));
+        $startDate = new Horde_Date(array('year' => $year, 'month' => $month, 'mday' => $startOfView));
+        $endDate = new Horde_Date(array('year' => $year, 'month' => $month, 'mday' => $startOfView + $daysInView,
+                                        'hour' => 23, 'min' => 59, 'sec' => 59));
         $startDate->correct();
         $endDate->correct();
 
@@ -117,18 +129,21 @@ class Horde_Block_Kronolith_month extends Horde_Block {
         } else {
             $all_events = Kronolith::listEvents($startDate, $endDate, $GLOBALS['display_calendars']);
         }
+        if (is_a($all_events, 'PEAR_Error')) {
+            return '<em>' . $all_events->getMessage() . '</em>';
+        }
 
         $weeks = array();
         $weekday = 0;
         $week = -1;
-        for ($day = $startOfView; $day < $startOfView + $daysInView; $day++) {
+        for ($day = $startOfView; $day < $startOfView + $daysInView; ++$day) {
             $dayStamp = mktime(0, 0, 0, $month, $day, $year);
 
             if ($weekday == 7) {
                 $weekday = 0;
             }
             if ($weekday == 0) {
-                $week++;
+                ++$week;
                 $html .= '</tr><tr>';
             }
 
@@ -152,9 +167,14 @@ class Horde_Block_Kronolith_month extends Horde_Block {
                  * list them. */
                 $day_events = '';
                 foreach ($all_events[$dayStamp] as $event) {
-                    $day_events .= date($prefs->getValue('twentyFour') ? 'G:i' : 'g:ia', $event->start->timestamp()) . ' - ' . date($prefs->getValue('twentyFour') ? 'G:i' : 'g:ia', $event->end->timestamp());
-                    $day_events .= ($event->getLocation()) ? ' (' . $event->getLocation() . ')' : '';
-                    $day_events .= ' ' . $event->getTitle() . "\n";
+                    if ($event->isAllDay()) {
+                        $day_events .= _("All day");
+                    } else {
+                        $day_events .= $event->start->strftime($prefs->getValue('twentyFour') ? '%R' : '%I:%M%p') . '-' . $event->end->strftime($prefs->getValue('twentyFour') ? '%R' : '%I:%M%p');
+                    }
+                    $day_events .= ':'
+                        . (($event->getLocation()) ? ' (' . $event->getLocation() . ')' : '')
+                        . ' ' . $event->getTitle() . "\n";
                 }
                 $cell = Horde::linkTooltip($url, _("View Day"), '', '', '', $day_events) . date('j', $dayStamp) . '</a>';
             } else {
@@ -168,7 +188,7 @@ class Horde_Block_Kronolith_month extends Horde_Block {
             }
 
             $html .= $cell . '</td>';
-            $weekday++;
+            ++$weekday;
         }
 
         return $html . '</tr></table>';
